==> grizzly-framework-2.3.16-sources.jar: org/glassfish/grizzly/ConnectorHandler.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2008-2013 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.grizzly;

import java.util.concurrent.Future;

/**
 * Client side connector handler API.
 * <tt>ConnectorHandler</tt> is responsible for creating and initializing
 * {@link Connection}, and optionally connect it to a specific local/remote
 * address.
 *
 * @author Alexey Stashok
 */
public interface ConnectorHandler<E> {

    /**
     * Creates, initializes and establishes {@link Connection} to the specific
     * <code>remoteAddress</code>.
     *
     * @param remoteAddress remote address to connect to
     * @return {@link Future} of connect operation, which could be used to get
     * resulting {@link Connection}
     */
    public Future<Connection> connect(E remoteAddress);

    /**
     * Creates, initializes and establishes {@link Connection} to the specific
     * <code>remoteAddress</code>.
     *
     * @param remoteAddress remote address to connect to
     * @param completionHandler {@link CompletionHandler}
     */
    public void connect(E remoteAddress,
            CompletionHandler<Connection> completionHandler);

    /**
     * Creates, initializes {@link Connection}, binds it to the specific local
     * and remote <code>remoteAddress</code>.
     *
     * @param remoteAddress remote address to connect to
     * @param localAddress local address to bind a {@link Connection} to
     * @return {@link Future} of connect operation, which could be used to get
     * resulting {@link Connection}
     */
    public Future<Connection> connect(E remoteAddress, E localAddress);

    /**
     * Creates, initializes {@link Connection}, binds it to the specific local
     * and remote <code>remoteAddress</code>.
     *
     * @param remoteAddress remote address to connect to
     * @param localAddress local address to bind a {@link Connection} to
     * @param completionHandler {@link CompletionHandler}
     */
    public void connect(E remoteAddress,
            E localAddress,
            CompletionHandler<Connection> completionHandler);
}

==> grizzly-framework-2.4.3-sources.jar: org/glassfish/grizzly/ConnectorHandler.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2008-2015 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.grizzly;

import java.util.concurrent.Future;

/**
 * Client side connector handler API.
 * <tt>ConnectorHandler</tt> is responsible for creating and initializing
 * {@link Connection}, and optionally connect it to a specific local/remote
 * address.
 *
 * @author Alexey Stashok
 */
public interface ConnectorHandler<E> {

    /**
     * Creates, initializes and establishes {@link Connection} to the specific
     * <code>remoteAddress</code>.
     *
     * @param remoteAddress remote address to connect to
     * @return {@link Future} of connect operation, which could be used to get
     * resulting {@link Connection}
     */
    Future<Connection> connect(E remoteAddress);

    /**
     * Creates, initializes and establishes {@link Connection} to the specific
     * <code>remoteAddress</code>.
     *
     * @param remoteAddress remote address to connect to
     * @param completionHandler {@link CompletionHandler}
     */
    void connect(E remoteAddress,
                 CompletionHandler<Connection> completionHandler);

    /**
     * Creates, initializes {@link Connection}, binds it to the specific local
     * and remote <code>remoteAddress</code>.
     *
     * @param remoteAddress remote address to connect to
     * @param localAddress local address to bind a {@link Connection} to
     * @return {@link Future} of connect operation, which could be used to get
     * resulting {@link Connection}
     */
    Future<Connection> connect(E remoteAddress, E localAddress);

    /**
     * Creates, initializes {@link Connection}, binds it to the specific local
     * and remote <code>remoteAddress</code>.
     *
     * @param remoteAddress remote address to connect to
     * @param localAddress local address to bind a {@link Connection} to
     * @param completionHandler {@link CompletionHandler}
     */
    void connect(E remoteAddress,
                 E localAddress,
                 CompletionHandler<Connection> completionHandler);
}
